@@ -6,7 +6,7 @@ from uuid import uuid4
 import random
 
 # module settings
-__version__ = '0.4.0'
+__version__ = '0.4.2'
 __all__ = [
     'is_string',
     'is_url',
@@ -36,7 +36,7 @@ URL_RE = re.compile(
     r'([a-z-]+://)'  # scheme
     r'([a-z_\d-]+:[a-z_\d-]+@)?'  # user:password
     r'(www\.)?'  # www.
-    r'((?<!\.)[a-z\d\.-]+\.[a-z]{2,6}|\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|localhost)'  # domain
+    r'((?<!\.)[a-z\d]+[a-z\d\.-]+\.[a-z]{2,6}|\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|localhost)'  # domain
     r'(:\d{2,})?'  # port number
     r'(/[a-z\d_%\+-]*)*'  # folders
     r'(\.[a-z\d_%\+-]+)*'  # file extension
